import { Hub } from '@sentry/hub';
import { TransactionContext } from '@sentry/types';
import { IDLE_TRANSACTION_FINISH_REASONS } from './constants';
import { Span, SpanRecorder } from './span';
import { Transaction } from './transaction';
export declare const DEFAULT_IDLE_TIMEOUT = 1000;
export declare const DEFAULT_FINAL_TIMEOUT = 30000;
export declare const HEARTBEAT_INTERVAL = 5000;
/**
 * @inheritDoc
 */
export declare class IdleTransactionSpanRecorder extends SpanRecorder {
    private readonly _pushActivity;
    private readonly _popActivity;
    transactionSpanId: string;
    constructor(_pushActivity: (id: string) => void, _popActivity: (id: string) => void, transactionSpanId?: string, maxlen?: number);
    /**
     * @inheritDoc
     */
    add(span: Span): void;
}
export declare type BeforeFinishCallback = (transactionSpan: IdleTransaction, endTimestamp: number) => void;
/**
 * An IdleTransaction is a transaction that automatically finishes. It does this by tracking child spans as activities.
 * You can have multiple IdleTransactions active, but if the `onScope` option is specified, the idle transaction will
 * put itself on the scope on creation.
 */
export declare class IdleTransaction extends Transaction {
    private readonly _idleHub?;
    /**
     * The time to wait in ms until the idle transaction will be finished.
     * @default 1000
     *
     * TODO: Make _idleTimeout and _finalTimeout required to reduce duplication when setting the options
     * in `BrowserTracing`. This is considered a breaking change to the IdleTransaction API,
     * so we need to make sure we communicate it with react native.
     */
    private readonly _idleTimeout;
    private readonly _onScope;
    /**
     * The final value that a transaction cannot exceed
     * @default 30000
     * @experimental
     * @internal
     */
    private readonly _finalTimeout;
    activities: Record<string, boolean>;
    /**
     *
     * Defaults to `externalFinish`, which means transaction.finish() was called outside of the idle transaction (for example,
     * by a navigation transaction ending the previous pageload/navigation in some routing instrumentation).
     * @default 'externalFinish'
     */
    finishReason: typeof IDLE_TRANSACTION_FINISH_REASONS[number];
    private _prevHeartbeatString;
    private _heartbeatCounter;
    private _finished;
    private readonly _beforeFinishCallbacks;
    /**
     * If a transaction is created and no activities are added, we want to make sure that
     * it times out properly. This is cleared and not used when activities are added.
     */
    private _idleTimeoutID;
    constructor(transactionContext: TransactionContext, _idleHub?: Hub | undefined, 
    /**
     * The time to wait in ms until the idle transaction will be finished.
     * @default 1000
     *
     * TODO: Make _idleTimeout and _finalTimeout required to reduce duplication when setting the options
     * in `BrowserTracing`. This is considered a breaking change to the IdleTransaction API,
     * so we need to make sure we communicate it with react native.
     */
    _idleTimeout?: number, _onScope?: boolean, 
    /**
     * The final value that a transaction cannot exceed
     * @default 30000
     * @experimental
     * @internal
     */
    _finalTimeout?: number);
    /** {@inheritDoc} */
    finish(endTimestamp?: number): string | undefined;
    /**
     * Register a callback function that gets excecuted before the transaction finishes.
     * Useful for cleanup or if you want to add any additional spans based on current context.
     *
     * This is exposed because users have no other way of running something before an idle transaction
     * finishes.
     */
    registerBeforeFinishCallback(callback: BeforeFinishCallback): void;
    /**
     * @inheritDoc
     */
    initSpanRecorder(maxlen?: number): void;
    /**
     * Cancels the existing idletimeout, if there is one
     */
    private _cancelIdleTimeout;
    /**
     * Creates an idletimeout
     */
    private _startIdleTimeout;
    /**
     * Start tracking a specific activity.
     * @param spanId The span id that represents the activity
     */
    private _pushActivity;
    /**
     * Remove an activity from usage
     * @param spanId The span id that represents the activity
     */
    private _popActivity;
    /**
     * Checks when entries of this.activities are not changing for 3 beats.
     * If this occurs we finish the transaction.
     */
    private _beat;
    /**
     * Pings the heartbeat
     */
    private _pingHeartbeat;
}
//# sourceMappingURL=idletransaction.d.ts.map